/*
 * fd_main.h
 *
 * This file is the header file used in the Form Designer
 *
 * Written by Mark Overmars
 *
 * Version 2.1b
 * Date  Nov  3, 1992
 */

#include "stdio.h"
#include "forms.h"

/******** in fd_main.c    *********/

extern long main_window;	/* The identifier of the main window */
extern int changed;		/* Whether the file has changed. */
extern char main_name[];	/* Main creation routine name */

/******** in fd_rubber.c  *********/

/* Contains routines for drawing rubberband boxes. */

void set_step_size(float);
/* sets the stepsize */

float get_step_size();
/* returns the stepsize */

void set_bounding_box(float, float, float, float);
/* sets the bounding box in which the drawing occurs */

void get_mouse_pos(float *, float *);
/* returns the position of the mouse in world coordinates*/

void move_box(float *, float *, float *, float *, int);
/* drag a box around until the user releases a mouse button */

void scale_box(float *, float *, float *, float *);
/* scales a box until the user releases a left mouse button */

/******** in fd_select.c *********/

/* Contains the routines that deal with the maintenance of the
   current selection of objects */

int is_selected(FL_OBJECT *);
/* Returns whether the object is selected. */

void addto_selection(FL_OBJECT *);
/* Adds an object to a selection */

void addgroupto_selection(FL_OBJECT *);
/* Adds a group of objects to a selection */

void deletefrom_selection(FL_OBJECT *);
/* Deletes an object from a selection */

void clear_selection();
/* Clears the current selection */

void deletegroupfrom_selection(FL_OBJECT *);
/* Deletes a group of objects from a selection */

void draw_selbox();
/* Draws the box around the selected objects */

void handle_select();
/* Change the selection when user puhed mouse. */

void handle_move();
/* Moves or scales the selection. */

void select_all();
/* Selects all objectsin the form */

void change_selection();
/* Changes the atributes of the selection */

void align_selection(int);
/* Aligns the objects in the selection */

void show_selection();
/* Makes the selection visible. */

void hide_selection();
/* Makes the selection invisible. */

void raise_selection();
/* Raises the selection */

void lower_selection();
/* Lower the selection */

void cut_selection();
/* Deletes all objects in the selection  and put them in a buffer*/

void paste_selection();
/* Puts elements from buffer into form */

void copy_selection();
/* Copies objects in selection to buffer */

void group_selection();
/* Turns objects in the selection into a group. */

void flatten_selection();
/* Removes begin and end groups from the selection. */

/******** in fd_attribs.c **********/

/* Contains routines to set and change attributes of objects. */

int change_object(FL_OBJECT *, int);
/* changes the settings for an object */

void change_type(FL_OBJECT *, int);
/* Changes the type of a particular object. */

void set_attribs(FL_OBJECT *, int, int, int, int, int, float, int, char []);
/* sets all attributes for an object */

void set_label(FL_OBJECT *, char []);
/* Sets the object label (interpreting \n's). */

char *get_label(FL_OBJECT *);
/* Returns the object label (turning NL's into \n's). */

FL_OBJECT *copy_object(FL_OBJECT *);
/* Make an exact copy of an object */

/******** in fl_file.c    ********/

/* Contains all routines that deal with saving and loading forms. */

void read_form(FILE *, char *);
/* Reads a form description */

void write_form(FILE *, FL_FORM *, char []);
/* Writes a form description */

/******** in fl_print.c   ********/

/* Contains all routines that deal with printing forms in C format. */

void print_form(FILE *, FL_FORM *, char []);
/* Prints a form in C-format */

void print_callbacks(FILE *, FL_FORM *);

void print_objects(FILE *, FL_FORM *, char []);
/* For making the header file */

/******** in fd_forms.c   *********/

/* Contains the routines that maintain the collection of forms. */

#define MAXFRM	100
/* Maximal number of forms allowed. */

extern FL_FORM *cur_form;
/* The current form under construction */

void redraw_the_form(int);
/* Redraws the current form. The argument indicates whether the background
   should be redrawn. */

void load_forms(int, char *);
/* loads the forms from a file */

int save_forms(char *);
/* saves the forms to a file, returns whether actually saved */

/******** fd_groups.c *********/

/* Contains the routines that deal with groups. */

#define MAXGROUP 100
/* Maximal number of groups in a form. */

void fillin_groups();
/* Fills in the groups in the current form. */

/******** fd_names.c  **********/

/* Contains the routines that keep track of the object names */

void get_object_name(FL_OBJECT *, char *, char *, char *);
/* returns the names of an object */

void set_object_name(FL_OBJECT *, char *, char *, char *);
/* returns the names of an object */

/******** fd_objects.c *********/

/* Contains the different object classes and types. */

#define MAXTYPE		20
/* Maximal number of different types per class. */

#define MAXCLASS	50
/* Maximal number of object classes. */

extern int cur_class;
/* The current class of object to be added */

void init_classes();
/* Initializes all the classes and types. */

FL_OBJECT *add_an_object(int, int, float, float, float, float);
/* adds an object to the current form */

char *find_class_name(int);
/* Returns a pointer to the name of the class */

int find_class_maxtype(int);
/* Returns the number of types in the class */

FL_OBJECT *find_class_default(int);
/* Returns the default object in the class */

char *find_type_name(int, int);
/* Returns a pointer to the name of the type in the class */
